@@ -1,16 +1,16 @@
 from __future__ import absolute_import, division, print_function
 
-from .hub import Hub, HubListener
-from .data import Data
-from .link_manager import LinkManager
-from .registry import Registry
-from .message import (DataCollectionAddMessage,
-                      DataCollectionDeleteMessage,
-                      DataAddComponentMessage)
-from .util import disambiguate
+from glue.core.util import disambiguate
+from glue.core.message import (DataCollectionAddMessage,
+                               DataCollectionDeleteMessage,
+                               DataAddComponentMessage)
+from glue.core.registry import Registry
+from glue.core.link_manager import LinkManager
+from glue.core.data import Data
+from glue.core.hub import Hub, HubListener
+from glue.config import settings
+from glue.utils import as_list
 
-from ..config import settings
-from ..utils import as_list
 
 __all__ = ['DataCollection']
 
@@ -24,7 +24,7 @@ class DataCollection(HubListener):
        * Providing a way to retrieve and store data
        * Broadcasting messages when data are added or removed
        * Keeping each managed data set's list of
-         :class:`~glue.core.data.DerivedComponent` instances up-to-date
+         :class:`~glue.core.component.DerivedComponent` instances up-to-date
        * Creating the hub that all other objects should use to communicate
          with one another (stored in ``self.hub``)
     """
@@ -187,7 +187,7 @@ class DataCollection(HubListener):
 
         :returns: A new :class:`~glue.core.subset_group.SubsetGroup`
         """
-        from .subset_group import SubsetGroup
+        from glue.core.subset_group import SubsetGroup
         color = settings.SUBSET_COLORS[self._sg_count % len(settings.SUBSET_COLORS)]
         self._sg_count += 1
         label = label or "%i" % (self._sg_count)
