@@ -53,30 +53,31 @@ starting from 1.
 
 from __future__ import absolute_import, division, print_function
 
-from itertools import count
-from collections import defaultdict
+import os
 import json
 import types
 import logging
+from io import BytesIO
+from itertools import count
+from collections import defaultdict
+from base64 import b64encode, b64decode
 from inspect import isgeneratorfunction
 
 import numpy as np
 
-from .subset import (OPSYM, SYMOP, CompositeSubsetState,
-                     SubsetState, Subset, RoiSubsetState,
-                     InequalitySubsetState, RangeSubsetState)
-from .data import (Data, Component, ComponentID, DerivedComponent,
-                   CoordinateComponent)
-from . import (VisualAttributes, ComponentLink, DataCollection)
-from .component_link import CoordinateComponentLink
-from ..utils import lookup_class
-from .roi import Roi
-from . import glue_pickle as gp
-from .. import core
-from .subset_group import coerce_subset_groups
-from ..external import six
-from io import BytesIO
-from base64 import b64encode, b64decode
+from glue.external import six
+from glue import core
+from glue.core.data import (Data, Component, ComponentID, DerivedComponent,
+                            CoordinateComponent)
+from glue.core.subset import (OPSYM, SYMOP, CompositeSubsetState,
+                              SubsetState, Subset, RoiSubsetState,
+                              InequalitySubsetState, RangeSubsetState)
+from glue.core import (VisualAttributes, ComponentLink, DataCollection)
+from glue.core.component_link import CoordinateComponentLink
+from glue.core.roi import Roi
+from glue.core import glue_pickle as gp
+from glue.core.subset_group import coerce_subset_groups
+from glue.utils import lookup_class
 
 
 literals = tuple([type(None), float, int, bytes, bool, list, tuple])
@@ -85,7 +86,30 @@ if six.PY2:
     literals += (long,)
 literals += (np.ScalarType,)
 
-_lookup = lookup_class
+# We need to make sure that we don't break backward-compatibility when we move
+# classes/functions around in Glue, so we have a file that maps the old paths to
+# the new location, and we read this in to PATH_PATCHES.
+PATCH_FILE = os.path.abspath(os.path.join(os.path.dirname(__file__),
+                             'state_path_patches.txt'))
+
+# For Mac app, need to get file from source directory
+if not os.path.exists(PATCH_FILE) and 'site-packages.zip' in PATCH_FILE:
+    PATCH_FILE = PATCH_FILE.replace('site-packages.zip', 'glue')
+
+PATH_PATCHES = {}
+for line in open(PATCH_FILE):
+    before, after = line.strip().split(' -> ')
+    PATH_PATCHES[before.strip()] = after.strip()
+
+
+def lookup_class_with_patches(name):
+    """
+    A wrapper to lookup_class that also patches paths to ensure
+    backward-compatibility when functions/classes are moved around.
+    """
+    while name in PATH_PATCHES:
+        name = PATH_PATCHES[name]
+    return lookup_class(name)
 
 
 class GlueSerializeError(RuntimeError):
@@ -372,7 +396,7 @@ class GlueUnSerializer(object):
 
     def _dispatch(self, rec):
 
-        typ = _lookup(rec['_type'])
+        typ = lookup_class_with_patches(rec['_type'])
 
         if typ is None:
             raise GlueSerializeError("Unkonwn type %s" % rec['_type'])
@@ -460,7 +484,7 @@ def _save_composite_subset_state(state, context):
 
 @loader(CompositeSubsetState)
 def _load_composite_subset_state(rec, context):
-    cls = _lookup(rec['_type'])
+    cls = lookup_class_with_patches(rec['_type'])
     result = cls(context.object(rec['state1']),
                  context.object(rec['state2']))
     return result
@@ -593,7 +617,7 @@ def _load_data_collection_2(rec, context):
 def _save_data(data, context):
 
     return dict(components=[(context.id(c),
-                            context.id(data.get_component(c)))
+                             context.id(data.get_component(c)))
                             for c in data._components],
                 subsets=[context.id(s) for s in data.subsets],
                 label=data.label,
@@ -753,8 +777,8 @@ def _load_coordinate_component_link(rec, context):
 @saver(types.FunctionType)
 def _save_function(function, context):
     ref = "%s.%s" % (function.__module__, function.__name__)
-    if _lookup(ref) is function:
-        l = _lookup(ref)
+    if lookup_class_with_patches(ref) is function:
+        l = lookup_class_with_patches(ref)
         return {'function': ref}
     return {'pickle': gp.dumps(function).encode('base64')}
 
@@ -763,7 +787,7 @@ def _save_function(function, context):
 def _load_function(rec, context):
     if 'pickle' in rec:
         return gp.loads(rec['pickle'].decode('base64'))
-    return _lookup(rec['function'])
+    return lookup_class_with_patches(rec['function'])
 
 
 @saver(core.Session)
