@@ -1,26 +1,26 @@
 from __future__ import absolute_import, division, print_function
 
-import operator
 import numbers
+import operator
 
 import numpy as np
 
-from .visual import VisualAttributes
-from .decorators import memoize
-from .message import SubsetDeleteMessage, SubsetUpdateMessage
-from .exceptions import IncompatibleAttribute
-from .registry import Registry
-from .util import split_component_view
-from ..utils import view_shape
-from ..external.six import PY3
-from .contracts import contract
-from .roi import CategoricalRoi
+from glue.external.six import PY3
+from glue.core.roi import CategoricalROI
+from glue.core.contracts import contract
+from glue.core.util import split_component_view
+from glue.core.registry import Registry
+from glue.core.exceptions import IncompatibleAttribute
+from glue.core.message import SubsetDeleteMessage, SubsetUpdateMessage
+from glue.core.decorators import memoize
+from glue.core.visual import VisualAttributes
+from glue.config import settings
+from glue.utils import view_shape
 
-from ..config import settings
 
 __all__ = ['Subset', 'SubsetState', 'RoiSubsetState', 'CompositeSubsetState',
            'OrState', 'AndState', 'XorState', 'InvertState',
-           'ElementSubsetState', 'RangeSubsetState']
+           'ElementSubsetState', 'RangeSubsetState', 'combine_multiple']
 
 OPSYM = {operator.ge: '>=', operator.gt: '>',
          operator.le: '<=', operator.lt: '<',
@@ -276,7 +276,7 @@ class Subset(object):
         mask = np.short(self.to_mask())
         if format == 'fits':
             try:
-                from ..external.astro import fits
+                from astropy.io import fits
                 fits.writeto(file_name, mask, clobber=True)
             except ImportError:
                 raise ImportError("Cannot write mask -- requires astropy")
@@ -286,7 +286,7 @@ class Subset(object):
     @contract(file_name='string')
     def read_mask(self, file_name):
         try:
-            from ..external.astro import fits
+            from astropy.io import fits
             mask = fits.open(file_name)[0].data
         except ImportError:
             raise ImportError("Cannot read mask -- requires astropy")
@@ -449,10 +449,10 @@ class RoiSubsetState(SubsetState):
         return result
 
 
-class CategoricalRoiSubsetState(SubsetState):
+class CategoricalROISubsetState(SubsetState):
 
     def __init__(self, att=None, roi=None):
-        super(CategoricalRoiSubsetState, self).__init__()
+        super(CategoricalROISubsetState, self).__init__()
         self.att = att
         self.roi = roi
 
@@ -469,7 +469,7 @@ class CategoricalRoiSubsetState(SubsetState):
         return result.ravel()
 
     def copy(self):
-        result = CategoricalRoiSubsetState()
+        result = CategoricalROISubsetState()
         result.att = self.att
         result.roi = self.roi
         return result
@@ -477,8 +477,8 @@ class CategoricalRoiSubsetState(SubsetState):
     @staticmethod
     def from_range(component, att, lo, hi):
 
-        roi = CategoricalRoi.from_range(component, lo, hi)
-        subset = CategoricalRoiSubsetState(roi=roi,
+        roi = CategoricalROI.from_range(component, lo, hi)
+        subset = CategoricalROISubsetState(roi=roi,
                                            att=att)
         return subset
 
@@ -505,6 +505,37 @@ class RangeSubsetState(SubsetState):
         return RangeSubsetState(self.lo, self.hi, self.att)
 
 
+class MultiRangeSubsetState(SubsetState):
+    """
+    A subset state defined by multiple discontinuous ranges
+
+    Parameters
+    ----------
+    pairs : list
+        A list of (lo, hi) tuples
+    """
+
+    def __init__(self, pairs, att=None):
+        super(MultiRangeSubsetState, self).__init__()
+        self.pairs = pairs
+        self.att = att
+
+    @property
+    def attributes(self):
+        return (self.att,)
+
+    @contract(data='isinstance(Data)', view='array_view')
+    def to_mask(self, data, view=None):
+        x = data[self.att, view]
+        result = np.zeros_like(x, dtype=bool)
+        for lo, hi in self.pairs:
+            result |= (x >= lo) & (x <= hi)
+        return result
+
+    def copy(self):
+        return MultiRangeSubsetState(self.pairs, self.att)
+
+
 class CompositeSubsetState(SubsetState):
     op = None
 
@@ -648,10 +679,10 @@ class ElementSubsetState(SubsetState):
 class InequalitySubsetState(SubsetState):
 
     def __init__(self, left, right, op):
-        from .component_link import ComponentLink
+        from glue.core.component_link import ComponentLink
 
         super(InequalitySubsetState, self).__init__()
-        from .data import ComponentID
+        from glue.core.data import ComponentID
         valid_ops = [operator.gt, operator.ge,
                      operator.lt, operator.le,
                      operator.eq, operator.ne]
@@ -685,7 +716,6 @@ class InequalitySubsetState(SubsetState):
 
     @memoize
     def to_mask(self, data, view=None):
-        from .data import ComponentID
         left = self._left
         if not isinstance(self._left, numbers.Number):
             left = data[self._left, view]
@@ -713,3 +743,13 @@ def _combine(subsets, operator):
     result = Subset(None)
     result.subset_state = state
     return result
+
+
+def combine_multiple(subsets, operator):
+    if len(subsets) == 0:
+        return SubsetState()
+    else:
+        combined = subsets[0]
+        for subset in subsets[1:]:
+            combined = operator(combined, subset)
+        return combined
