@@ -9,20 +9,20 @@ import pytest
 import numpy as np
 from mock import MagicMock
 
+from glue.tests.helpers import requires_astropy
+
 from .. import DataCollection, ComponentLink
 from ..data import Data, Component
-from ..subset import (Subset, SubsetState,
-                      ElementSubsetState, RoiSubsetState, RangeSubsetState)
-from ..subset import OrState
-from ..subset import AndState
-from ..subset import XorState
-from ..subset import InvertState
 from ..message import SubsetDeleteMessage
 from ..registry import Registry
+from ..subset import (Subset, SubsetState,
+                      ElementSubsetState, RoiSubsetState, RangeSubsetState)
+from ..subset import AndState
+from ..subset import InvertState
+from ..subset import OrState
+from ..subset import XorState
 from .test_state import clone
 
-from ...tests.helpers import requires_astropy
-
 
 class TestSubset(object):
 
@@ -315,7 +315,7 @@ class TestSubsetIo(object):
         fobj, tmp = tempfile.mkstemp()
 
         self.subset.write_mask(tmp)
-        from ...external.astro import fits
+        from astropy.io import fits
         data = fits.open(tmp)[0].data
         expected = np.array([[0, 1, 1, 1],
                              [0, 0, 0, 0],
