@@ -4,9 +4,9 @@ from __future__ import absolute_import, division, print_function
 
 import sys
 import optparse
-from .logger import logger
 
 from glue import __version__
+from glue.logger import logger
 
 
 def parse(argv):
@@ -95,9 +95,14 @@ def die_on_error(msg):
             try:
                 return func(*args, **kwargs)
             except Exception as e:
+
                 import traceback
-                from . import qt
-                from .utils.qt import QMessageBoxPatched as QMessageBox
+
+                # Make sure application has been started
+                from glue.external.qt import get_qapp
+                get_qapp()
+
+                from glue.utils.qt import QMessageBoxPatched as QMessageBox
                 m = "%s\n%s" % (msg, e)
                 detail = str(traceback.format_exc())
                 if len(m) > 500:
@@ -117,17 +122,17 @@ def die_on_error(msg):
 @die_on_error("Error restoring Glue session")
 def restore_session(gluefile):
     """Load a .glu file and return a DataCollection, Hub tuple"""
-    from glue.qt.glue_application import GlueApplication
+    from glue.app.qt import GlueApplication
     return GlueApplication.restore_session(gluefile)
 
 
 @die_on_error("Error reading data file")
 def load_data_files(datafiles):
     """Load data files and return a DataCollection"""
-    import glue
+    from glue.core.data_collection import DataCollection
     from glue.core.data_factories import auto_data, load_data
 
-    dc = glue.core.DataCollection()
+    dc = DataCollection()
     for df in datafiles:
         dc.append(load_data(df, auto_data))
     return dc
@@ -151,7 +156,7 @@ def start_glue(gluefile=None, config=None, datafiles=None):
     :type datafiles: list of str
     """
     import glue
-    from glue.qt.glue_application import GlueApplication
+    from glue.app.qt import GlueApplication
 
     # Start off by loading plugins. We need to do this before restoring
     # the session or loading the configuration since these may use existing
@@ -179,10 +184,10 @@ def start_glue(gluefile=None, config=None, datafiles=None):
 
     session = glue.core.Session(data_collection=data, hub=hub)
     ga = GlueApplication(session=session)
-    #ga.show()
-    #splash.close()
-    #ga.raise_()
-    #QApplication.instance().processEvents()
+    # ga.show()
+    # splash.close()
+    # ga.raise_()
+    # QApplication.instance().processEvents()
     return ga.start()
 
 
@@ -199,13 +204,13 @@ def execute_script(script):
 
 def get_splash():
     """Instantiate a splash screen"""
-    from .external.qt.QtGui import QSplashScreen, QPixmap
-    from .external.qt.QtCore import Qt
+    from glue.external.qt import QtGui
+    from glue.external.qt.QtCore import Qt
     import os
 
     pth = os.path.join(os.path.dirname(__file__), 'logo.png')
-    pm = QPixmap(pth)
-    splash = QSplashScreen(pm, Qt.WindowStaysOnTopHint)
+    pm = QtGui.QPixmap(pth)
+    splash = QtGui.QSplashScreen(pm, Qt.WindowStaysOnTopHint)
     splash.show()
 
     return splash
@@ -264,7 +269,7 @@ def load_plugins():
     import setuptools
     logger.info("Loading external plugins using setuptools=={0}".format(setuptools.__version__))
 
-    from ._plugin_helpers import iter_plugin_entry_points, PluginConfig
+    from glue._plugin_helpers import iter_plugin_entry_points, PluginConfig
     config = PluginConfig.load()
 
     for item in iter_plugin_entry_points():
