@@ -1,9 +1,15 @@
 # Define decorators that can be used for pytest tests
 
-import pytest
+from __future__ import absolute_import, division, print_function
 
+import os
+import zlib
+import tempfile
+from contextlib import contextmanager
 from distutils.version import LooseVersion
 
+import pytest
+
 
 def make_skipper(module, label=None, version=None):
     label = label or module
@@ -33,7 +39,7 @@ ASTRODENDRO_INSTALLED, requires_astrodendro = make_skipper('astrodendro')
 SCIPY_INSTALLED, requires_scipy = make_skipper('scipy',
                                                label='SciPy')
 
-PIL_INSTALLED, requires_pil = make_skipper('pil', label='PIL')
+PIL_INSTALLED, requires_pil = make_skipper('PIL', label='PIL')
 
 SKIMAGE_INSTALLED, requires_skimage = make_skipper('skimage',
                                                    label='scikit-image')
@@ -53,3 +59,35 @@ requires_pil_or_skimage = pytest.mark.skipif(str(not SKIMAGE_INSTALLED and not P
 GINGA_INSTALLED, requires_ginga = make_skipper('ginga')
 
 H5PY_INSTALLED, requires_h5py = make_skipper('h5py')
+
+PYQT4_INSTALLED, requires_pyqt4 = make_skipper('PyQt4')
+PYQT5_INSTALLED, requires_pyqt5 = make_skipper('PyQt5')
+PYSIDE_INSTALLED, requires_pyside = make_skipper('PySide')
+
+QT_INSTALLED = PYQT4_INSTALLED or PYQT5_INSTALLED or PYSIDE_INSTALLED
+
+requires_qt = pytest.mark.skipif(str(not QT_INSTALLED),
+                                 reason='An installation of Qt is required')
+
+
+@contextmanager
+def make_file(contents, suffix, decompress=False):
+    """Context manager to write data to a temporary file,
+    and delete on exit
+
+    :param contents: Data to write. string
+    :param suffix: File suffix. string
+    """
+    if decompress:
+        contents = zlib.decompress(contents)
+
+    try:
+        _, fname = tempfile.mkstemp(suffix=suffix)
+        with open(fname, 'wb') as outfile:
+            outfile.write(contents)
+        yield fname
+    finally:
+        try:
+            os.unlink(fname)
+        except WindowsError:  # on Windows the unlink can fail
+            pass
\ No newline at end of file
